import os
import sys
from textwrap import dedent
import tempfile
import shutil

from . import helpers as thelpers

from cloudinit import importer

DS_FILES = {
    "foo.py": dedent("""\
        class FooDS(object):
           pass
   
        def get_datasources():
            return ([{'priority': 3, 'version': 2, 'class': FooDS}])
    """),
    "foo2.py": dedent("""\
        class FooDS2(object):
            pass

        def get_datasources():
            return ([{'priority': 3, 'version': 2, 'class': FooDS2}])
    """),
    "wark.py": dedent("""\
        def ignorethis():
            pass
    """),
    "foodir/__init__.py": dedent("""
        from .foo import get_datasources
    """),
    "foodir/foo.py": dedent("""
        class CheeseDS2(object):
            pass

        class WineDS2(object):
            pass

        def get_datasources():
            return ([{'priority': 3, 'version': 2, 'class': CheeseDS2}, 
                     {'priority': 2, 'version': 2, 'class': WineDS2}])
    """)
}


class TestDataSourceLoader(thelpers.TestCase):
    def get_tmpdir(self):
        tmpdir = tempfile.mkdtemp()
        self.addCleanup(shutil.rmtree, tmpdir)
        return tmpdir

    def test_basic_load(self):
        tmpd = self.get_tmpdir()
        thelpers.populate_dir(tmpd, DS_FILES)
        modules = importer.load_datasource_modules([tmpd])
        self.assertEqual(sorted([f.__name__ for f in modules]),
                         sorted(['foo', 'foo2', 'foodir']))

    def test_basic_get_datasources(self):
        tmpd = self.get_tmpdir()
        thelpers.populate_dir(tmpd, DS_FILES)
        sources = importer.get_datasources([tmpd])
        self.assertEqual(['WineDS2', 'FooDS', 'FooDS2', 'CheeseDS2'],
                         [f.get('class').__name__ for f in sources])

# vi: ts=4 expandtab
